==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/eu.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Biltegia ez dago eskuragarri",
    "Storage invalid" : "Biltegi bliogabea",
    "Unknown error" : "Errore ezezaguna",
    "Could not move %s - File with this name already exists" : "Ezin da %s mugitu - Izen hau duen fitxategia dagoeneko existitzen da",
    "Could not move %s" : "Ezin dira fitxategiak mugitu %s",
    "Permission denied" : "Baimena Ukatua",
    "The target folder has been moved or deleted." : "Jatorrizko karpeta mugitu edo ezabatu da.",
    "The name %s is already used in the folder %s. Please choose a different name." : "%s izena dagoeneko erabilita dago %s karpetan. Mesdez hautatu izen ezberdina.",
    "Error when creating the file" : "Errorea fitxategia sortzerakoan",
    "Error when creating the folder" : "Errorea karpeta sortzerakoan",
    "Unable to set upload directory." : "Ezin da igoera direktorioa ezarri.",
    "Invalid Token" : "Lekuko baliogabea",
    "No file was uploaded. Unknown error" : "Ez da fitxategirik igo. Errore ezezaguna",
    "There is no error, the file uploaded with success" : "Ez da errorerik egon, fitxategia ongi igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Igotako fitxategiak php.ini fitxategian ezarritako upload_max_filesize muga gainditu du:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Igotako fitxategia HTML formularioan zehaztutako MAX_FILE_SIZE direktiba baino handidagoa da.",
    "The uploaded file was only partially uploaded" : "Igotako fitxategiaren zati bat bakarrik igo da",
    "No file was uploaded" : "Ez da fitxategirik igo",
    "Missing a temporary folder" : "Aldi bateko karpeta falta da",
    "Failed to write to disk" : "Errore bat izan da diskoan idazterakoan",
    "Not enough storage available" : "Ez dago behar aina leku erabilgarri,",
    "Upload failed. Could not find uploaded file" : "Igoerak huts egin du. Ezin izan da igotako fitxategia aurkitu",
    "Upload failed. Could not get file info." : "Igoerak huts egin du. Ezin izan da fitxategiaren informazioa eskuratu.",
    "Invalid directory." : "Baliogabeko karpeta.",
    "Files" : "Fitxategiak",
    "All files" : "Fitxategi guztiak",
    "Favorites" : "Gogokoak",
    "Home" : "Etxekoa",
    "Close" : "Itxi",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} igo karpeta bat delako edo 0 byte dituelako",
    "Total file size {size1} exceeds upload limit {size2}" : "Fitxategiaren tamainak {size1} igotzeko muga {size2} gainditzen du",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, zu {size1} igotzen ari zara baina bakarrik {size2} libre dago",
    "Upload cancelled." : "Igoera ezeztatuta",
    "Could not get result from server." : "Ezin da zerbitzaritik emaitzik lortu",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fitxategien igoera martxan da. Orria orain uzteak igoera ezeztatutko du.",
    "Actions" : "Ekintzak",
    "Download" : "Deskargatu",
    "Rename" : "Berrizendatu",
    "Delete" : "Ezabatu",
    "Details" : "Xehetasunak",
    "Select" : "hautatu",
    "Pending" : "Zain",
    "Unable to determine date" : "Ezin izan da data zehaztu",
    "Error moving file." : "Errorea fitxategia mugitzean.",
    "Error moving file" : "Errorea fitxategia mugitzean",
    "Error" : "Errorea",
    "{new_name} already exists" : "{new_name} dagoeneko existitzen da",
    "Could not rename file" : "Ezin izan da fitxategia berrizendatu",
    "Could not create file" : "Ezin izan da fitxategia sortu",
    "Could not create folder" : "Ezin izan da karpeta sortu",
    "Error deleting file." : "Errorea fitxategia ezabatzerakoan.",
    "No entries in this folder match '{filter}'" : "Karpeta honetan ez dago sarrerarik '{filter}' iragazkiarekin bat egiten dutenak",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "_%n folder_::_%n folders_" : ["karpeta %n","%n karpeta"],
    "_%n file_::_%n files_" : ["fitxategi %n","%n fitxategi"],
    "{dirs} and {files}" : "{dirs} eta {files}",
    "You don’t have permission to upload or create files here" : "Ez duzu fitxategiak hona igotzeko edo hemen sortzeko baimenik",
    "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n igotzen","%n fitxategi igotzen"],
    "New" : "Berria",
    "\"{name}\" is an invalid file name." : "\"{name}\" ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegiratzea beterik dago, ezingo duzu aurrerantzean fitxategirik igo edo sinkronizatu!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegiratzea nahiko beterik dago (%{usedSpacePercent})",
    "Favorited" : "Gogokoa",
    "Favorite" : "Gogokoa",
    "Upload" : "Igo",
    "Text file" : "Testu fitxategia",
    "Folder" : "Karpeta",
    "New folder" : "Karpeta berria",
    "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu da</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fitxategi edo karpeta bat <strong>ezabatu da</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fitxategia edo karpeta <strong>berrezarri</strong> da",
    "You created %1$s" : "Zuk sortua %1$s",
    "%2$s created %1$s" : "%2$sk sortua %1$s",
    "%1$s was created in a public folder" : "%1$s sortu da karpeta publiko batean",
    "You changed %1$s" : "%1$s aldatu duzu",
    "%2$s changed %1$s" : "%2$sk aldatuta %1$s",
    "You deleted %1$s" : "%1$s ezabatu duzu",
    "%2$s deleted %1$s" : "%2$sk ezabatuta %1$s",
    "You restored %1$s" : "Zuk %1$s berrezarri duzu",
    "%2$s restored %1$s" : "%2$sk %1$s berrezarri du",
    "%s could not be renamed as it has been deleted" : "%s ezin izan da berrizendatu ezabatua zegoen eta",
    "%s could not be renamed" : "%s ezin da berrizendatu",
    "Upload (max. %s)" : "Igo (max. %s)",
    "File handling" : "Fitxategien kudeaketa",
    "Maximum upload size" : "Igo daitekeen gehienezko tamaina",
    "max. possible: " : "max, posiblea:",
    "Save" : "Gorde",
    "Settings" : "Ezarpenak",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\">helbidea erabili zure fitxategiak WebDAV bidez eskuratzeko</a>",
    "Cancel upload" : "Ezeztatu igoera",
    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Select all" : "Hautatu dena",
    "Upload too large" : "Igoera handiegia da",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiak zerbitzari honek igotzeko onartzen duena baino handiagoak dira.",
    "Files are being scanned, please wait." : "Fitxategiak eskaneatzen ari da, itxoin mezedez.",
    "Currently scanning" : "Eskaneatzen une honetan",
    "No favorites" : "Gogokorik ez",
    "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpeta hemen agertuko dira"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/eu.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Biltegia ez dago eskuragarri",
    "Storage invalid" : "Biltegi bliogabea",
    "Unknown error" : "Errore ezezaguna",
    "Unable to set upload directory." : "Ezin da igoera direktorioa ezarri.",
    "Invalid Token" : "Lekuko baliogabea",
    "No file was uploaded. Unknown error" : "Ez da fitxategirik igo. Errore ezezaguna",
    "There is no error, the file uploaded with success" : "Ez da errorerik egon, fitxategia ongi igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Igotako fitxategiak php.ini fitxategian ezarritako upload_max_filesize muga gainditu du:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Igotako fitxategia HTML formularioan zehaztutako MAX_FILE_SIZE direktiba baino handidagoa da.",
    "The uploaded file was only partially uploaded" : "Igotako fitxategiaren zati bat bakarrik igo da",
    "No file was uploaded" : "Ez da fitxategirik igo",
    "Missing a temporary folder" : "Aldi bateko karpeta falta da",
    "Failed to write to disk" : "Errore bat izan da diskoan idazterakoan",
    "Not enough storage available" : "Ez dago behar aina leku erabilgarri,",
    "The target folder has been moved or deleted." : "Jatorrizko karpeta mugitu edo ezabatu da.",
    "Upload failed. Could not find uploaded file" : "Igoerak huts egin du. Ezin izan da igotako fitxategia aurkitu",
    "Upload failed. Could not get file info." : "Igoerak huts egin du. Ezin izan da fitxategiaren informazioa eskuratu.",
    "Invalid directory." : "Baliogabeko karpeta.",
    "Files" : "Fitxategiak",
    "All files" : "Fitxategi guztiak",
    "Favorites" : "Gogokoak",
    "Home" : "Etxekoa",
    "Close" : "Itxi",
    "Upload cancelled." : "Igoera ezeztatuta",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} igo karpeta bat delako edo 0 byte dituelako",
    "Total file size {size1} exceeds upload limit {size2}" : "Fitxategiaren tamainak {size1} igotzeko muga {size2} gainditzen du",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, zu {size1} igotzen ari zara baina bakarrik {size2} libre dago",
    "Could not get result from server." : "Ezin da zerbitzaritik emaitzik lortu",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fitxategien igoera martxan da. Orria orain uzteak igoera ezeztatutko du.",
    "Actions" : "Ekintzak",
    "Download" : "Deskargatu",
    "Rename" : "Berrizendatu",
    "Delete" : "Ezabatu",
    "Disconnect storage" : "Deskonektatu biltegia",
    "Unshare" : "Ez elkarbanatu",
    "Details" : "Xehetasunak",
    "Select" : "hautatu",
    "Pending" : "Zain",
    "Unable to determine date" : "Ezin izan da data zehaztu",
    "No entries in this folder match '{filter}'" : "Karpeta honetan ez dago sarrerarik '{filter}' iragazkiarekin bat egiten dutenak",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatuta",
    "_%n folder_::_%n folders_" : ["karpeta %n","%n karpeta"],
    "_%n file_::_%n files_" : ["fitxategi %n","%n fitxategi"],
    "{dirs} and {files}" : "{dirs} eta {files}",
    "You don’t have permission to upload or create files here" : "Ez duzu fitxategiak hona igotzeko edo hemen sortzeko baimenik",
    "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n igotzen","%n fitxategi igotzen"],
    "New" : "Berria",
    "\"{name}\" is an invalid file name." : "\"{name}\" ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegiratzea beterik dago, ezingo duzu aurrerantzean fitxategirik igo edo sinkronizatu!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegiratzea nahiko beterik dago (%{usedSpacePercent})",
    "Favorited" : "Gogokoa",
    "Favorite" : "Gogokoa",
    "Folder" : "Karpeta",
    "New folder" : "Karpeta berria",
    "Upload" : "Igo",
    "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu da</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fitxategi edo karpeta bat <strong>ezabatu da</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fitxategia edo karpeta <strong>berrezarri</strong> da",
    "You created %1$s" : "Zuk sortua %1$s",
    "%2$s created %1$s" : "%2$sk sortua %1$s",
    "%1$s was created in a public folder" : "%1$s sortu da karpeta publiko batean",
    "You changed %1$s" : "%1$s aldatu duzu",
    "%2$s changed %1$s" : "%2$sk aldatuta %1$s",
    "You deleted %1$s" : "%1$s ezabatu duzu",
    "%2$s deleted %1$s" : "%2$sk ezabatuta %1$s",
    "You restored %1$s" : "Zuk %1$s berrezarri duzu",
    "%2$s restored %1$s" : "%2$sk %1$s berrezarri du",
    "Upload (max. %s)" : "Igo (max. %s)",
    "File handling" : "Fitxategien kudeaketa",
    "Maximum upload size" : "Igo daitekeen gehienezko tamaina",
    "max. possible: " : "max, posiblea:",
    "Save" : "Gorde",
    "Settings" : "Ezarpenak",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\">helbidea erabili zure fitxategiak WebDAV bidez eskuratzeko</a>",
    "Cancel upload" : "Ezeztatu igoera",
    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Select all" : "Hautatu dena",
    "Upload too large" : "Igoera handiegia da",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiak zerbitzari honek igotzeko onartzen duena baino handiagoak dira.",
    "No favorites" : "Gogokorik ez",
    "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpeta hemen agertuko dira",
    "Text file" : "Testu fitxategia"
},
"nplurals=2; plural=(n != 1);");
